@@ -164,7 +164,7 @@ def call(name, *args, **kwargs):
     """Invoke the dependency identified by `name` with
     the given positional and keyword arguments.
     """
-    pass
+    return require(name)(*args, **kwargs)
 
 
 def check():
