@@ -1,11 +1,16 @@
 """Setup inversion-of-control through entrypoints."""
 import pkg_resources
+import os
 
 from . import provider
 
 
 IOC_ENTRYPOINT_NAME = 'ioc.providers'
-
+IOC_SEARCH_PATH = list(
+    filter(bool, str.split(os.getenv('IOC_SEARCH_PATH') or '', os.pathsep))
+)
+if not IOC_SEARCH_PATH:
+    IOC_SEARCH_PATH = ['etc/ioc.conf', 'etc/ioc.conf.d/*']
 IS_CONFIGURED = False
 
 
@@ -28,11 +33,14 @@ def setup():
     if IS_CONFIGURED:
         return
 
+    import ioc
     for name, module in get_providers():
         if not hasattr(module, 'setup_ioc'):
             continue
         module.setup_ioc()
 
+    ioc.load_config(IOC_SEARCH_PATH, override=True)
+
     IS_CONFIGURED = True
 
 
